Authors — Pyblosxom 1.5 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyblosxom 1.5 documentation »

# Authors

Pyblosxom was originally written by Wari Wahab and is now maintained by Will Kahn-Greene.

Over the years, Pyblosxom has had many contributors who have helped make the project what it is today (in no particular order):

- Martin Kraft
- Joerg Wendland
- Enrico Zini
- Gpal. V
- Nathan Gray
- Alexandre Patry
- Brian Warner
- Ryan Thiessen
- Dewayne Christensen
- Joe Gregorio
- James Henstridge
- Myers Carpenter
- Scott C.
- Axel Kollmorgen
- Thenault Sylvain
- Russell Nelson
- IWS
- Joseph Reagle
- Tollef Fog Heen
- Colin Walters
- Norbert Tretkowski
- David Stanek
- FX
- Zoom Quiet
- Matej Cepl
- Andrew Kuchling
- Dieter Plaetinck
- Jordi Mallach
- Marius Gedminas
- Mikko Värri
- Robert Wall
- Ryan Barrett
- Sebastian Spaeth
- Steven Armstrong
- Ted Leung
- Wari Wahab
- Weakish Jakukyo
- Weakish Jiang
- Doug Ransom
- Abe Fettig
- Benjamin Mako Hill
- David Pashley
- David Geller
- Roberto De Almeida
- Akai
- Antonio “Willy” Malara

Many thanks for all their work and efforts!

### Navigation

- index
- modules |
- next |
- previous |
- Pyblosxom 1.5 documentation »